# jansbrainfuckkernel

![Logo](jansbrainfuckkernel/logo-svg.svg)

A jupyter kernel implementation of [brainfuck](https://github.com/benjamin-james/brainfuck).

## Installation

- `pip install jansbrainfuckkernel`
- to register the kernel with jupyter `jansbrainfuckkernel`

## Dev Installation

- download/clone this project
- open shell in project folder
- `pip install -e ./`
- then install kernelspec
- `jansbrainfuckkernel`
- or
- `jupyter kernelspec install --user jansbrainfuckkernel`

## Uninstall

- `jupyter kernelspec uninstall jansbrainfuckkernel`
- `pip uninstall jansbrainfuckkernel`
